@@ -10,7 +10,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""Kolla exception subclasses"""
+"""Kolla exception subclasses."""
 
 
 class KollaDirNotFoundException(Exception):
